download_data_wrds_ccm_links: Download CCM Links from WRDS

View source: R/download_data_wrds_ccm_links.R

download_data_wrds_ccm_linksR Documentation

Description

Downloads data from the WRDS CRSP/Compustat Merged (CCM) links database. It allows users to specify the type of links (linktype) and the primacy of the link (linkprim).

Usage

download_data_wrds_ccm_links(linktype = c("LU", "LC"), linkprim = c("P", "C"))

Arguments

linktype

A character vector indicating the type of link to download. The default is c("LU", "LC"), where "LU" stands for "Link Up" and "LC" for "Link CRSP".

linkprim

A character vector indicating the primacy of the link. Default is c("P", "C"), where "P" indicates primary and "C" indicates conditional links.

Value

A data frame with the columns permno, gvkey, linkdt, and linkenddt, where linkenddt is the end date of the link, and missing end dates are replaced with today's date.

See Also

Other WRDS functions: disconnect_connection(), download_data_wrds(), download_data_wrds_compustat(), download_data_wrds_crsp(), download_data_wrds_fisd(), download_data_wrds_trace_enhanced(), get_wrds_connection(), set_wrds_credentials()

Examples

## Not run: 
  ccm_links <- download_data_wrds_ccm_links(linktype = "LU", linkprim = "P")

## End(Not run)


tidyfinance documentation built on July 3, 2026, 1:09 a.m.