list_supported_datasets_macro_predictors: List Supported Macro Predictor Datasets

View source: R/list_supported_datasets.R

list_supported_datasets_macro_predictorsR Documentation

List Supported Macro Predictor Datasets

Description

Returns a tibble with the supported macro predictor datasets provided by Goyal-Welch, including their frequencies (monthly, quarterly, annual). All datasets reference the same source file, "PredictorData2022.xlsx" for the year 2022. Additionally, it annotates each dataset with the domain "Goyal-Welch".

Usage

list_supported_datasets_macro_predictors()

Value

A tibble with columns: type (the type of dataset), dataset_name (the file name of the dataset, which is the same for all types), and domain (the domain to which the dataset belongs, always "Goyal-Welch").

See Also

Other utility functions: create_summary_statistics(), get_available_huggingface_files(), list_supported_datasets(), list_supported_datasets_ff(), list_supported_datasets_ff_legacy(), list_supported_datasets_other(), list_supported_datasets_pseudo(), list_supported_datasets_wrds(), list_supported_indexes(), list_tidy_finance_chapters(), open_tidy_finance_website(), trim(), validate_dates(), winsorize()


tidyfinance documentation built on June 26, 2026, 1:07 a.m.