list_supported_indexes: List Supported Indexes

View source: R/list_supported_indexes.R

list_supported_indexesR Documentation

List Supported Indexes

Description

Returns a tibble containing information about supported financial indexes. Each index is associated with a URL that points to a CSV file containing the holdings of the index. Additionally, each index has a corresponding skip value, which indicates the number of preamble lines in the CSV file. It is kept for compatibility; download_data_constituents() detects the header row automatically.

Usage

list_supported_indexes()

Value

A tibble with three columns:

index

The name of the financial index (e.g., "DAX", "S&P 500").

url

The URL to the CSV file containing the holdings data for the index.

skip

The number of preamble lines in the CSV file. Kept for compatibility; the header row is detected automatically.

See Also

Other utility functions: create_summary_statistics(), get_available_huggingface_files(), list_supported_datasets(), list_supported_datasets_ff(), list_supported_datasets_ff_legacy(), list_supported_datasets_macro_predictors(), list_supported_datasets_other(), list_supported_datasets_pseudo(), list_supported_datasets_wrds(), list_supported_jkp_factors(), list_tidy_finance_chapters(), open_tidy_finance_website(), trim(), validate_dates(), winsorize()

Examples

supported_indexes <- list_supported_indexes()
print(supported_indexes)


tidyfinance documentation built on Oct. 6, 2026, 1:06 a.m.