list_supported_jkp_factors: List Supported Global Factor Data Regions and Factors

View source: R/download_data_jkp.R

list_supported_jkp_factorsR Documentation

List Supported Global Factor Data Regions and Factors

Description

Queries the live availability manifest of Global Factor Data and returns the regions and selectors that can be passed to download_data_jkp().

Usage

list_supported_jkp_factors(region = NULL, dataset = "factors")

Arguments

region

Optional. A region or country code. If provided, the function returns the selectors (factor codes, or industry classifications when dataset = "industry") available for that region. If NULL (the default), it returns the available region codes.

dataset

The Global Factor Data product to query, one of "factors" (default), "portfolios", or "industry".

Value

A tibble. When region is NULL, it has a single region column listing the available region codes. When region is provided, it has a region column and a factor column listing the selectors (factor codes, or industry classifications when dataset = "industry") available for that region.

See Also

Other utility functions: create_summary_statistics(), get_available_huggingface_files(), list_supported_datasets(), list_supported_datasets_ff(), list_supported_datasets_ff_legacy(), list_supported_datasets_macro_predictors(), list_supported_datasets_other(), list_supported_datasets_pseudo(), list_supported_datasets_wrds(), list_supported_indexes(), list_tidy_finance_chapters(), open_tidy_finance_website(), trim(), validate_dates(), winsorize()

Examples


  list_supported_jkp_factors()
  list_supported_jkp_factors("usa")
  list_supported_jkp_factors("usa", dataset = "portfolios")


tidyfinance documentation built on July 3, 2026, 1:09 a.m.