open_tidy_finance_website: Open Tidy Finance Website or Specific Chapter in Browser

View source: R/open_tidy_finance_website.R

open_tidy_finance_websiteR Documentation

Open Tidy Finance Website or Specific Chapter in Browser

Description

Opens the main Tidy Finance website or a specific chapter within the site in the user's default web browser. If a chapter is specified, the function constructs the URL to access the chapter directly.

Usage

open_tidy_finance_website(chapter = NULL)

Arguments

chapter

An optional character string specifying the chapter to open. If NULL (the default), the function opens the main page of Tidy Finance with R. If a chapter name is provided (e.g., "beta-estimation"), the function opens the corresponding chapter's page (e.g., "beta-estimation.html"). If the chapter name does not exist, then the function opens the main page.

Value

Invisible NULL. The function is called for its side effect of opening a web page.

See Also

Other utility functions: create_summary_statistics(), get_available_huggingface_files(), list_supported_datasets(), list_supported_datasets_ff(), list_supported_datasets_ff_legacy(), list_supported_datasets_macro_predictors(), list_supported_datasets_other(), list_supported_datasets_pseudo(), list_supported_datasets_wrds(), list_supported_indexes(), list_supported_jkp_factors(), list_tidy_finance_chapters(), trim(), validate_dates(), winsorize()

Examples

## Not run: 
open_tidy_finance_website()
open_tidy_finance_website("beta-estimation")

## End(Not run)


tidyfinance documentation built on July 3, 2026, 1:09 a.m.