View source: R/assign_portfolio.R
| assign_portfolio | R Documentation |
Assigns data points to portfolios based on a specified sorting variable and
the selected function to compute breakpoints. Users can specify a function
to compute breakpoints. The function must take data and
sorting_variable as the first two arguments. Additional arguments are
passed with a named list breakpoint_options(). The function needs to
return an ascending vector of breakpoints. By default, breakpoints are
computed with compute_breakpoints(). The default column names can be
modified using data_options().
assign_portfolio(
data,
sorting_variable,
breakpoint_options = NULL,
breakpoint_function = compute_breakpoints,
data_options = NULL
)
data |
A data frame containing the dataset for portfolio assignment. |
sorting_variable |
A string specifying the column name in |
breakpoint_options |
An optional named list of arguments passed to
|
breakpoint_function |
A function to compute breakpoints. The default
is set to |
data_options |
A list of class |
A vector of integer portfolio assignments for each row in the
input data.
Other portfolio functions:
breakpoint_options(),
compute_breakpoints(),
compute_long_short_returns(),
compute_portfolio_returns(),
data_options(),
filter_options(),
filter_sorting_data(),
implement_portfolio_sort(),
portfolio_sort_options()
set.seed(42)
data <- data.frame(
id = 1:100,
exchange = sample(c("NYSE", "NASDAQ"), 100, replace = TRUE),
market_cap = 1:100
)
assign_portfolio(data, "market_cap", breakpoint_options(n_portfolios = 5))
assign_portfolio(
data,
"market_cap",
breakpoint_options(
percentiles = c(0.2, 0.4, 0.6, 0.8),
breakpoints_exchanges = c("NYSE")
)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.