| data_options | R Documentation |
Creates a list of data options of class tidyfinance_data_options used for
TidyFinance-related functions. These options map the specific data variables
to the TidyFinance naming conventions, allowing functions to flexibly work
with different datasets by specifying the relevant column names. Additional
options can be passed through ....
data_options(
id = "permno",
date = "date",
exchange = "exchange",
mktcap_lag = "mktcap_lag",
ret_excess = "ret_excess",
portfolio = "portfolio",
siccd = "siccd",
price = "prc_adj",
listing_age = "listing_age",
be = "be",
earnings = "ib",
...
)
id |
A character string representing the entity variable (defaults to
|
date |
A character string representing the date variable (defaults to
|
exchange |
A character string representing the exchange variable
(defaults to |
mktcap_lag |
A character string representing the market capitalization
lag variable (defaults to |
ret_excess |
A character string representing the excess return variable
(defaults to |
portfolio |
A character string representing the portfolio variable
(defaults to |
siccd |
A character string representing the Standard Industrial
Classification code variable (defaults to |
price |
A character string representing the (adjusted) price variable
(defaults to |
listing_age |
A character string representing the listing age variable
(defaults to |
be |
A character string representing the book equity variable (defaults
to |
earnings |
A character string representing the earnings variable
(defaults to |
... |
Additional arguments to be included in the data options list. |
A list of class tidyfinance_data_options containing the specified
data options.
Other portfolio functions:
assign_portfolio(),
breakpoint_options(),
compute_breakpoints(),
compute_long_short_returns(),
compute_portfolio_returns(),
filter_options(),
filter_sorting_data(),
implement_portfolio_sort(),
portfolio_sort_options()
data_options(
id = "permno",
date = "date",
exchange = "exchange"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.