View source: R/disconnect_connection.R
| disconnect_connection | R Documentation |
Safely disconnects an established database connection using the DBI package.
disconnect_connection(con)
con |
A database connection object created by DBI::dbConnect or any similar function that establishes a connection to a database. |
TRUE, invisibly. Throws an error if the disconnection fails.
Other WRDS functions:
download_data_wrds(),
download_data_wrds_ccm_links(),
download_data_wrds_compustat(),
download_data_wrds_crsp(),
download_data_wrds_fisd(),
download_data_wrds_trace_enhanced(),
get_wrds_connection(),
set_wrds_credentials()
## Not run:
con <- get_wrds_connection()
disconnect_connection(con)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.