download_data_osap: Download and Process Open Source Asset Pricing Data

View source: R/download_data_osap.R

download_data_osapR Documentation

Download and Process Open Source Asset Pricing Data

Description

Downloads the data from Open Source Asset Pricing from Google Sheets using a specified sheet ID, processes the data by converting column names to snake_case, and optionally filters the data based on a provided date range.

Usage

download_data_osap(
  start_date = NULL,
  end_date = NULL,
  sheet_id = "1JyhcF5PRKHcputlioxlu5j5GyLo4JYyY"
)

Arguments

start_date

Optional. A character string or Date object in "YYYY-MM-DD" format specifying the start date for the data. If not provided, the full dataset is returned.

end_date

Optional. A character string or Date object in "YYYY-MM-DD" format specifying the end date for the data. If not provided, the full dataset is returned.

sheet_id

A character string representing the Google Sheet ID from which to download the data. Default is "1JyhcF5PRKHcputlioxlu5j5GyLo4JYyY".

Value

A tibble containing the processed data. The column names are converted to snake_case, and the data is filtered by the specified date range if start_date and end_date are provided.

See Also

Other download functions: download_data(), download_data_constituents(), download_data_factors_ff(), download_data_factors_q(), download_data_fred(), download_data_huggingface(), download_data_macro_predictors(), download_data_risk_free(), download_data_stock_prices(), download_factor_library_grid(), download_factor_library_ids()

Examples


  osap <- download_data_osap(
    start_date = "2020-01-01", end_date = "2020-06-30"
  )


tidyfinance documentation built on June 26, 2026, 1:07 a.m.