View source: R/download_data_osap.R
| download_data_osap | R Documentation |
Downloads the data from Open Source Asset Pricing from Google Sheets using a specified sheet ID, processes the data by converting column names to snake_case, and optionally filters the data based on a provided date range.
download_data_osap(
start_date = NULL,
end_date = NULL,
sheet_id = "1JyhcF5PRKHcputlioxlu5j5GyLo4JYyY"
)
start_date |
Optional. A character string or Date object in "YYYY-MM-DD" format specifying the start date for the data. If not provided, the full dataset is returned. |
end_date |
Optional. A character string or Date object in "YYYY-MM-DD" format specifying the end date for the data. If not provided, the full dataset is returned. |
sheet_id |
A character string representing the Google Sheet ID
from which to download the data. Default is
|
A tibble containing the processed data. The column names
are converted to snake_case, and the data is filtered by the
specified date range if start_date and end_date are provided.
Other download functions:
download_data(),
download_data_constituents(),
download_data_factors_ff(),
download_data_factors_q(),
download_data_fred(),
download_data_huggingface(),
download_data_macro_predictors(),
download_data_risk_free(),
download_data_stock_prices(),
download_factor_library_grid(),
download_factor_library_ids()
osap <- download_data_osap(
start_date = "2020-01-01", end_date = "2020-06-30"
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.