View source: R/download_data_wrds.R
| download_data_wrds | R Documentation |
Acts as a wrapper to download data from various WRDS datasets including CRSP, Compustat, and CCM links based on the specified dataset. It is designed to handle different datasets by redirecting to the appropriate specific data download function.
download_data_wrds(
dataset = NULL,
start_date = NULL,
end_date = NULL,
type = deprecated(),
...
)
dataset |
A string specifying the dataset to download. Supported values: "crsp_monthly", "crsp_daily" for CRSP data, "compustat_annual", "compustat_quarterly" for Compustat data, "ccm_links" for CCM links data, "fisd" for FISD data, or "trace_enhanced" for TRACE data. |
start_date |
Optional. A character string or Date object in "YYYY-MM-DD" format specifying the start date for the data. If not provided, a subset of the dataset is returned. |
end_date |
Optional. A character string or Date object in "YYYY-MM-DD" format specifying the end date for the data. If not provided, a subset of the dataset is returned. |
type |
|
... |
Additional arguments passed to specific download functions
depending on the |
A data frame containing the requested data, with the structure
and contents depending on the specified dataset.
Other WRDS functions:
disconnect_connection(),
download_data_wrds_ccm_links(),
download_data_wrds_compustat(),
download_data_wrds_crsp(),
download_data_wrds_fisd(),
download_data_wrds_trace_enhanced(),
get_wrds_connection(),
set_wrds_credentials()
## Not run:
crsp_monthly <- download_data_wrds(
"crsp_monthly", "2020-01-01", "2020-12-31"
)
compustat_annual <- download_data_wrds(
"compustat_annual", "2020-01-01", "2020-12-31"
)
ccm_links <- download_data_wrds("ccm_links")
fisd <- download_data_wrds("fisd")
trace_enhanced <- download_data_wrds(
"trace_enhanced", cusips = "00101JAH9"
)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.