View source: R/download_data_wrds_ccm_links.R
| download_data_wrds_ccm_links | R Documentation |
Downloads data from the WRDS CRSP/Compustat Merged (CCM) links
database. It allows users to specify the type of links (linktype) and the
primacy of the link (linkprim).
download_data_wrds_ccm_links(linktype = c("LU", "LC"), linkprim = c("P", "C"))
linktype |
A character vector indicating the type of link to download.
The default is |
linkprim |
A character vector indicating the primacy of the link.
Default is |
A data frame with the columns permno, gvkey, linkdt, and
linkenddt, where linkenddt is the end date of the link, and missing end
dates are replaced with today's date.
Other WRDS functions:
disconnect_connection(),
download_data_wrds(),
download_data_wrds_compustat(),
download_data_wrds_crsp(),
download_data_wrds_fisd(),
download_data_wrds_trace_enhanced(),
get_wrds_connection(),
set_wrds_credentials()
## Not run:
ccm_links <- download_data_wrds_ccm_links(linktype = "LU", linkprim = "P")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.