download_data_wrds_trace_enhanced: Download Enhanced TRACE Data from WRDS

View source: R/download_data_wrds_trace_enhanced.R

download_data_wrds_trace_enhancedR Documentation

Download Enhanced TRACE Data from WRDS

Description

Establishes a connection to the WRDS database to download the specified CUSIPs trade messages from the Trade Reporting and Compliance Engine (TRACE). The trade data is cleaned as suggested by Dick-Nielsen (2009, 2014).

Usage

download_data_wrds_trace_enhanced(cusips, start_date = NULL, end_date = NULL)

Arguments

cusips

A character vector specifying the 9-digit CUSIPs to download.

start_date

Optional. A character string or Date object in "YYYY-MM-DD" format specifying the start date for the data. If not provided, a subset of the dataset is returned.

end_date

Optional. A character string or Date object in "YYYY-MM-DD" format specifying the end date for the data. If not provided, a subset of the dataset is returned.

Value

A data frame containing the cleaned trade messages from TRACE for the selected CUSIPs over the time window specified. Output variables include identifying information (i.e., CUSIP, trade date/time) and trade-specific information (i.e., price/yield, volume, counterparty, and reporting side).

References

Dick-Nielsen, J. (2009). Liquidity biases in TRACE. Journal of Fixed Income, 19(2), 43-55. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.3905/jfi.2009.19.2.043")}

Dick-Nielsen, J. (2014). How to clean enhanced TRACE data. Working Paper. \Sexpr[results=rd]{tools:::Rd_expr_doi("10.2139/ssrn.2337908")}

See Also

Other WRDS functions: disconnect_connection(), download_data_wrds(), download_data_wrds_ccm_links(), download_data_wrds_compustat(), download_data_wrds_crsp(), download_data_wrds_fisd(), get_wrds_connection(), set_wrds_credentials()

Examples

## Not run: 
download_data_wrds_trace_enhanced("00101JAH9", "2019-01-01", "2021-12-31")

## End(Not run)

tidyfinance documentation built on July 3, 2026, 1:09 a.m.