View source: R/filter_options.R
| filter_options | R Documentation |
Creates a list of filter options of class tidyfinance_filter_options used
for sample construction in TidyFinance-related functions. These options
control which observations are retained before portfolio sorting.
filter_options(
exclude_financials = FALSE,
exclude_utilities = FALSE,
min_stock_price = NULL,
min_size_quantile = NULL,
min_listing_age = NULL,
exclude_negative_book_equity = FALSE,
exclude_negative_earnings = FALSE,
...
)
exclude_financials |
A logical indicating whether to exclude financial
firms (SIC codes 6000–6799). Defaults to |
exclude_utilities |
A logical indicating whether to exclude utility
firms (SIC codes 4900–4999). Defaults to |
min_stock_price |
A single positive numeric specifying the minimum
stock price required to include an observation. |
min_size_quantile |
A single numeric strictly between 0 and 1
specifying the minimum cross-sectional size quantile (based on lagged
market cap) required to include an observation. |
min_listing_age |
A single non-negative integer or numeric specifying
the minimum number of months a stock must have been listed in CRSP.
|
exclude_negative_book_equity |
A logical indicating whether to exclude
observations with non-positive book equity. Defaults to |
exclude_negative_earnings |
A logical indicating whether to exclude
observations with non-positive earnings. Defaults to |
... |
Additional arguments to be included in the filter options list. |
A list of class tidyfinance_filter_options containing the
specified filter options.
Other portfolio functions:
assign_portfolio(),
breakpoint_options(),
compute_breakpoints(),
compute_long_short_returns(),
compute_portfolio_returns(),
data_options(),
filter_sorting_data(),
implement_portfolio_sort(),
portfolio_sort_options()
filter_options(
exclude_financials = TRUE,
exclude_utilities = TRUE,
min_stock_price = 1,
min_listing_age = 12
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.