View source: R/list_supported_datasets.R
| list_supported_datasets | R Documentation |
Aggregates and returns a comprehensive tibble of all supported datasets from different domains. It includes various datasets across different frequencies (daily, weekly, monthly, quarterly, annual) and models (e.g., q5 factors, Fama-French 3 and 5 factors, macro predictors).
list_supported_types() is a soft-deprecated alias for
list_supported_datasets().
list_supported_datasets(domain = NULL, as_vector = FALSE)
list_supported_types(domain = NULL, as_vector = FALSE)
domain |
A character vector to filter for domain-specific datasets (e.g., c("WRDS", "Fama-French")). |
as_vector |
Logical indicating whether datasets should be returned as a character vector instead of a data frame. |
A tibble aggregating all supported datasets with columns:
type (the type of dataset), dataset_name (a descriptive name or
file name of the dataset), and domain (the domain to which the
dataset belongs, e.g., "Global Q", "Fama-French", "Goyal-Welch").
Other utility functions:
create_summary_statistics(),
get_available_huggingface_files(),
list_supported_datasets_ff(),
list_supported_datasets_ff_legacy(),
list_supported_datasets_macro_predictors(),
list_supported_datasets_other(),
list_supported_datasets_pseudo(),
list_supported_datasets_wrds(),
list_supported_indexes(),
list_tidy_finance_chapters(),
open_tidy_finance_website(),
trim(),
validate_dates(),
winsorize()
# List all supported datasets as a data frame
list_supported_datasets()
# Filter by domain
list_supported_datasets(domain = "WRDS")
# List supported datasets as a vector
list_supported_datasets(as_vector = TRUE)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.