View source: R/list_supported_datasets.R
| list_supported_datasets_ff | R Documentation |
Returns a tibble with the supported Fama-French datasets, including their names and frequencies (daily, weekly, monthly). Each dataset type is associated with a specific Fama-French model (e.g., 3 factors, 5 factors). Additionally, it annotates each dataset with the domain "Fama-French".
list_supported_datasets_ff()
A tibble with columns: type (the type of dataset),
dataset_name (a descriptive name of the dataset), file_url (the
path of the source ZIP relative to Kenneth French's data library), and
domain (the domain to which the dataset belongs, always "Fama-French").
Other utility functions:
create_summary_statistics(),
get_available_huggingface_files(),
list_supported_datasets(),
list_supported_datasets_ff_legacy(),
list_supported_datasets_macro_predictors(),
list_supported_datasets_other(),
list_supported_datasets_pseudo(),
list_supported_datasets_wrds(),
list_supported_indexes(),
list_tidy_finance_chapters(),
open_tidy_finance_website(),
trim(),
validate_dates(),
winsorize()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.