View source: R/list_supported_datasets.R
| list_supported_datasets_q | R Documentation |
Returns a tibble with the supported Global Q datasets, including their names and frequencies (daily, weekly, weekly week-to-week, monthly, quarterly, annual). Each dataset type is associated with the Global Q model, specifically the q5 factors model for the year 2023. Additionally, it annotates each dataset with the domain "Global Q".
list_supported_datasets_q()
A tibble with columns: type (the type of dataset),
dataset_name (the file name of the dataset), and domain (the
domain to which the dataset belongs, always "Global Q").
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.