View source: R/list_supported_datasets.R
| list_supported_datasets_wrds | R Documentation |
Returns a tibble with the supported datasets provided via WRDS. Additionally, it annotates each dataset with the domain "WRDS".
list_supported_datasets_wrds()
A tibble with columns: type (the type of dataset),
dataset_name (the file name of the dataset), and domain (the
domain to which the dataset belongs, always "WRDS").
Other utility functions:
create_summary_statistics(),
get_available_huggingface_files(),
list_supported_datasets(),
list_supported_datasets_ff(),
list_supported_datasets_ff_legacy(),
list_supported_datasets_macro_predictors(),
list_supported_datasets_other(),
list_supported_datasets_pseudo(),
list_supported_indexes(),
list_supported_jkp_factors(),
list_tidy_finance_chapters(),
open_tidy_finance_website(),
trim(),
validate_dates(),
winsorize()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.