list_tidy_finance_chapters: List Chapters of Tidy Finance

View source: R/list_tidy_finance_chapters.R

list_tidy_finance_chaptersR Documentation

List Chapters of Tidy Finance

Description

Returns a character vector containing the names of the chapters available in the Tidy Finance resource. It provides a quick reference to the various topics covered.

Usage

list_tidy_finance_chapters()

Value

A character vector where each element is the name of a chapter available in the Tidy Finance resource. These names correspond to specific chapters in Tidy Finance with R.

See Also

Other utility functions: create_summary_statistics(), get_available_huggingface_files(), list_supported_datasets(), list_supported_datasets_ff(), list_supported_datasets_ff_legacy(), list_supported_datasets_macro_predictors(), list_supported_datasets_other(), list_supported_datasets_pseudo(), list_supported_datasets_wrds(), list_supported_indexes(), list_supported_jkp_factors(), open_tidy_finance_website(), trim(), validate_dates(), winsorize()

Examples

list_tidy_finance_chapters()


tidyfinance documentation built on July 3, 2026, 1:09 a.m.