View source: R/open_tidy_finance_website.R
| open_tidy_finance_website | R Documentation |
Opens the main Tidy Finance website or a specific chapter within the site in the user's default web browser. If a chapter is specified, the function constructs the URL to access the chapter directly.
open_tidy_finance_website(chapter = NULL)
chapter |
An optional character string specifying the chapter to open.
If |
Invisible NULL. The function is called for its side effect of
opening a web page.
Other utility functions:
create_summary_statistics(),
get_available_huggingface_files(),
list_supported_datasets(),
list_supported_datasets_ff(),
list_supported_datasets_ff_legacy(),
list_supported_datasets_macro_predictors(),
list_supported_datasets_other(),
list_supported_datasets_pseudo(),
list_supported_datasets_wrds(),
list_supported_indexes(),
list_supported_jkp_factors(),
list_tidy_finance_chapters(),
trim(),
validate_dates(),
winsorize()
## Not run:
open_tidy_finance_website()
open_tidy_finance_website("beta-estimation")
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.