View source: R/portfolio_sort_options.R
| portfolio_sort_options | R Documentation |
Creates a list of options of class tidyfinance_portfolio_sort_options that
bundles sample construction filters and breakpoint specifications for use
with implement_portfolio_sort().
portfolio_sort_options(
filter_options = NULL,
breakpoint_options_main,
breakpoint_options_secondary = NULL,
...
)
filter_options |
A list of class
|
breakpoint_options_main |
A list of class
|
breakpoint_options_secondary |
A list of class
|
... |
Additional arguments to be included in the options list. |
A list of class tidyfinance_portfolio_sort_options containing
the specified options.
Other portfolio functions:
assign_portfolio(),
breakpoint_options(),
compute_breakpoints(),
compute_long_short_returns(),
compute_portfolio_returns(),
data_options(),
filter_options(),
filter_sorting_data(),
implement_portfolio_sort()
portfolio_sort_options(
filter_options = filter_options(exclude_financials = TRUE),
breakpoint_options_main = breakpoint_options(n_portfolios = 10)
)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.