View source: R/set_wrds_credentials.R
| set_wrds_credentials | R Documentation |
Prompts the user to input their WRDS (Wharton Research Data Services)
username and password, and stores these credentials in a .Renviron file.
The user can choose to store the .Renviron file in either the project
directory or the home directory. If the .Renviron file already contains
WRDS credentials, the user will be asked if they want to overwrite the
existing credentials. Additionally, the user has the option to add the
.Renviron file to the .gitignore file to prevent it from being tracked by
version control.
set_wrds_credentials()
Invisibly returns TRUE. Displays messages to the user based on
their input and actions taken.
Other WRDS functions:
disconnect_connection(),
download_data_wrds(),
download_data_wrds_ccm_links(),
download_data_wrds_compustat(),
download_data_wrds_crsp(),
download_data_wrds_fisd(),
download_data_wrds_trace_enhanced(),
get_wrds_connection()
## Not run:
set_wrds_credentials()
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.