| validate_dates | R Documentation |
Checks that start_date and end_date are a valid pair, coerces them to
Date, and handles the case where both are NULL. When both are NULL and
use_default_range = TRUE, a default range spanning from two years ago to
one year ago is applied and reported to the user.
validate_dates(start_date, end_date, use_default_range = FALSE)
start_date |
A scalar coercible to |
end_date |
A scalar coercible to |
use_default_range |
A logical scalar. If |
A named list with elements start_date and end_date, both of
class Date (or NULL when no dates are provided and
use_default_range = FALSE).
Other utility functions:
create_summary_statistics(),
get_available_huggingface_files(),
list_supported_datasets(),
list_supported_datasets_ff(),
list_supported_datasets_ff_legacy(),
list_supported_datasets_macro_predictors(),
list_supported_datasets_other(),
list_supported_datasets_pseudo(),
list_supported_datasets_wrds(),
list_supported_indexes(),
list_tidy_finance_chapters(),
open_tidy_finance_website(),
trim(),
winsorize()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.